@@ -2,7 +2,7 @@ use 5.14.0;
 
 package Map::Metro::Plugin::Map::Gothenburg;
 
-our $VERSION = '0.1002'; # VERSION
+our $VERSION = '0.1003'; # VERSION
 # ABSTRACT: Map::Metro map for Gothenburg
 
 use Moose;
@@ -32,20 +32,24 @@ Map::Metro::Plugin::Map::Gothenburg - Map::Metro map for Gothenburg
 
 =head1 VERSION
 
-Version 0.1002, released 2015-01-21.
+Version 0.1003, released 2015-01-21.
 
 =head1 SYNOPSIS
 
     use Map::Metro;
     my $graph = Map::Metro->new('Gothenburg')->parse;
 
+Or:
+
+	$ map-metro.pl route Gothenburg Saltholmen Torp
+
 =head1 DESCRIPTION
 
 See L<Map::Metro> for usage information.
 
 =head1 Status
 
-This map contains:
+This map L<contains|Map::Metro::Plugin::Map::Gothenburg::Lines>:
 
 =over 4
 
